@@ -1,7 +1,7 @@
 """
 Type annotations for iotanalytics service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/type_defs/)
 
 Usage::
 
@@ -16,6 +16,7 @@ from datetime import datetime
 from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
+from typing_extensions import NotRequired
 
 from .literals import (
     ChannelStatusType,
@@ -118,14 +119,19 @@ __all__ = (
     "LambdaActivityTypeDef",
     "LateDataRuleConfigurationTypeDef",
     "LateDataRuleTypeDef",
+    "ListChannelsRequestListChannelsPaginateTypeDef",
     "ListChannelsRequestRequestTypeDef",
     "ListChannelsResponseTypeDef",
+    "ListDatasetContentsRequestListDatasetContentsPaginateTypeDef",
     "ListDatasetContentsRequestRequestTypeDef",
     "ListDatasetContentsResponseTypeDef",
+    "ListDatasetsRequestListDatasetsPaginateTypeDef",
     "ListDatasetsRequestRequestTypeDef",
     "ListDatasetsResponseTypeDef",
+    "ListDatastoresRequestListDatastoresPaginateTypeDef",
     "ListDatastoresRequestRequestTypeDef",
     "ListDatastoresResponseTypeDef",
+    "ListPipelinesRequestListPipelinesPaginateTypeDef",
     "ListPipelinesRequestRequestTypeDef",
     "ListPipelinesResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
@@ -1172,6 +1178,14 @@ class LateDataRuleTypeDef(_RequiredLateDataRuleTypeDef, _OptionalLateDataRuleTyp
     pass
 
 
+ListChannelsRequestListChannelsPaginateTypeDef = TypedDict(
+    "ListChannelsRequestListChannelsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListChannelsRequestRequestTypeDef = TypedDict(
     "ListChannelsRequestRequestTypeDef",
     {
@@ -1190,6 +1204,30 @@ ListChannelsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListDatasetContentsRequestListDatasetContentsPaginateTypeDef = TypedDict(
+    "_RequiredListDatasetContentsRequestListDatasetContentsPaginateTypeDef",
+    {
+        "datasetName": str,
+    },
+)
+_OptionalListDatasetContentsRequestListDatasetContentsPaginateTypeDef = TypedDict(
+    "_OptionalListDatasetContentsRequestListDatasetContentsPaginateTypeDef",
+    {
+        "scheduledOnOrAfter": Union[datetime, str],
+        "scheduledBefore": Union[datetime, str],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListDatasetContentsRequestListDatasetContentsPaginateTypeDef(
+    _RequiredListDatasetContentsRequestListDatasetContentsPaginateTypeDef,
+    _OptionalListDatasetContentsRequestListDatasetContentsPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListDatasetContentsRequestRequestTypeDef = TypedDict(
     "_RequiredListDatasetContentsRequestRequestTypeDef",
     {
@@ -1224,6 +1262,14 @@ ListDatasetContentsResponseTypeDef = TypedDict(
     },
 )
 
+ListDatasetsRequestListDatasetsPaginateTypeDef = TypedDict(
+    "ListDatasetsRequestListDatasetsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListDatasetsRequestRequestTypeDef = TypedDict(
     "ListDatasetsRequestRequestTypeDef",
     {
@@ -1242,6 +1288,14 @@ ListDatasetsResponseTypeDef = TypedDict(
     },
 )
 
+ListDatastoresRequestListDatastoresPaginateTypeDef = TypedDict(
+    "ListDatastoresRequestListDatastoresPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListDatastoresRequestRequestTypeDef = TypedDict(
     "ListDatastoresRequestRequestTypeDef",
     {
@@ -1260,6 +1314,14 @@ ListDatastoresResponseTypeDef = TypedDict(
     },
 )
 
+ListPipelinesRequestListPipelinesPaginateTypeDef = TypedDict(
+    "ListPipelinesRequestListPipelinesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListPipelinesRequestRequestTypeDef = TypedDict(
     "ListPipelinesRequestRequestTypeDef",
     {
